==> dolphin-17.12.2.tar.xz: dolphin-17.12.2/src/settings/general/statusbarsettingspage.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/
#ifndef STATUSBARSETTINGSPAGE_H
#define STATUSBARSETTINGSPAGE_H

#include <settings/settingspagebase.h>

class QCheckBox;

/**
 * @brief Tab page for the 'Status Bar' settings of the Dolphin settings dialog.
 */
class StatusBarSettingsPage : public SettingsPageBase
{
    Q_OBJECT

public:
    StatusBarSettingsPage(QWidget* parent);
    virtual ~StatusBarSettingsPage();

    /** @see SettingsPageBase::applySettings() */
    virtual void applySettings() Q_DECL_OVERRIDE;

    /** @see SettingsPageBase::restoreDefaults() */
    virtual void restoreDefaults() Q_DECL_OVERRIDE;

private:
    void loadSettings();

private:
    QCheckBox* m_showZoomSlider;
    QCheckBox* m_showSpaceInfo;
};

#endif

==> dolphin_18.08.0.orig.tar.xz: dolphin-18.08.0/src/settings/general/statusbarsettingspage.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/
#ifndef STATUSBARSETTINGSPAGE_H
#define STATUSBARSETTINGSPAGE_H

#include "settings/settingspagebase.h"

class QCheckBox;

/**
 * @brief Tab page for the 'Status Bar' settings of the Dolphin settings dialog.
 */
class StatusBarSettingsPage : public SettingsPageBase
{
    Q_OBJECT

public:
    explicit StatusBarSettingsPage(QWidget* parent);
    ~StatusBarSettingsPage() override;

    /** @see SettingsPageBase::applySettings() */
    void applySettings() override;

    /** @see SettingsPageBase::restoreDefaults() */
    void restoreDefaults() override;

private:
    void loadSettings();

private:
    QCheckBox* m_showZoomSlider;
    QCheckBox* m_showSpaceInfo;
};

#endif
